# Audio Signals API

::: veridex.audio.spectral.SpectralSignal
::: veridex.audio.wav2vec_signal.Wav2VecSignal
::: veridex.audio.aasist_signal.AASISTSignal
::: veridex.audio.breathing_signal.BreathingSignal
::: veridex.audio.silence.SilenceSignal
